.. _python:

Python Interface
================

This section of the documentation covers antelop's python interface, including how to use the interactive prompt, how to write scripts with antelop, and how to write custom analysis functions.

.. toctree::
   :maxdepth: 1
   :titlesonly:

   config
   interactive
   script
   run
   stlib
   analysis

